@@ -80,6 +80,7 @@ class Server(gateway.GatewayClient):
 
 
 if __name__ == '__main__':
+    import time
     logging.basicConfig(level=logging.INFO)
 
     class TestClass:
@@ -88,6 +89,9 @@ if __name__ == '__main__':
         def method(self):
             return 'baz'
 
+        def sleep(self, duration):
+            time.sleep(duration)
+
     server = Server()
     server.register_instance('test', TestClass())
     server.start()
\ No newline at end of file
